@@ -4,8 +4,6 @@
 ##
 __author__ = """Microsoft Corporation"""
 __email__ = "que-contacts@microsoft.com"
-__version__ = "0.3.0"
+__version__ = "0.3.1"
 
-from qiskit_qir.translate import (
-    to_qir_module
-)
+from qiskit_qir.translate import to_qir_module
